@@ -1,10 +1,8 @@
 """Pytest Cache Assert Configuration Object."""
 
-import warnings
 
 from beartype.typing import List
-from pydantic import Field
-from pydantic.dataclasses import dataclass
+from pydantic import BaseModel, Field
 
 from .cache_store import CacheStoreType, LocalJSONCacheStore
 from .config import CacheAssertContainerKeys, MissingConfigItemError, register, retrieve
@@ -13,15 +11,14 @@ from .converter import Converter
 from .validator import DictDiffValidator, ValidatorType
 
 
-@dataclass
-class AssertConfig:
+class AssertConfig(BaseModel):
     """User configuration data structure."""
 
     always_write: bool = False
     """Always write to the cached file so that diffs can be examined in the user's VCS."""
 
     cache_dir_rel_path: str = DEF_CACHE_DIR_NAME
-    """String relative directory from `tests/`. Default resolves to `tests/assert-cache/`."""
+    """String relative directory from `tests/` where default resolves to `tests/assert-cache/`."""
 
     cache_store: CacheStoreType = Field(default_factory=LocalJSONCacheStore)
     """Configurable class for managing the cache representation. Default is local JSON.
@@ -49,13 +46,6 @@ class AssertConfig:
 
     class Config:
         arbitrary_types_allowed = True
-        frozen = True
-
-    def __post_init_post_parse__(self) -> None:
-        """Register the configuration object."""
-        if self.always_write:
-            warnings.warn('User has configured always_write globally. Make sure to check-in files to a VCS')
-        register(CacheAssertContainerKeys.CONFIG, self)
 
 
 # Ensure that a default AssertConfig is always registered
